@@ -10,6 +10,7 @@
 #include "qwaylandlayersurface_p.h"
 #include "qwaylandxdgactivationv1_p.h"
 
+#include <QtWaylandClient/private/qwaylandinputdevice_p.h>
 #include <QtWaylandClient/private/qwaylandscreen_p.h>
 #include <QtWaylandClient/private/qwaylandsurface_p.h>
 #include <QtWaylandClient/private/qwaylandwindow_p.h>
@@ -124,13 +125,7 @@ void QWaylandLayerSurface::attachPopup(QtWaylandClient::QWaylandShellSurface *po
 
 void QWaylandLayerSurface::applyConfigure()
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
-    m_configuring = true;
-#endif
     window()->resizeFromApplyConfigure(m_pendingSize);
-#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
-    m_configuring = false;
-#endif
 }
 
 void QWaylandLayerSurface::setDesiredSize(const QSize &size)
@@ -181,25 +176,12 @@ void QWaylandLayerSurface::setLayer(uint32_t layer)
         set_layer(layer);
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
-void QWaylandLayerSurface::setWindowGeometry(const QRect &geometry)
-{
-    if (m_configuring) {
-        return;
-    }
-
-    if (m_interface->desiredSize().isNull()) {
-        setDesiredSize(geometry.size());
-    }
-}
-#else
 void QWaylandLayerSurface::setWindowSize(const QSize &size)
 {
     if (m_interface->desiredSize().isNull()) {
         setDesiredSize(size);
     }
 }
-#endif
 
 bool QWaylandLayerSurface::requestActivate()
 {
@@ -219,7 +201,7 @@ bool QWaylandLayerSurface::requestActivate()
         const auto focusWindow = QGuiApplication::focusWindow();
         const auto wlWindow = focusWindow ? static_cast<QtWaylandClient::QWaylandWindow *>(focusWindow->handle()) : window();
         if (const auto seat = wlWindow->display()->lastInputDevice()) {
-            const auto tokenProvider = activation->requestXdgActivationToken(wlWindow->display(), wlWindow->wlSurface(), 0, QString());
+            const auto tokenProvider = activation->requestXdgActivationToken(wlWindow->display(), wlWindow->wlSurface(), seat->serial(), QString());
             connect(tokenProvider, &QWaylandXdgActivationTokenV1::done, this, [this](const QString &token) {
                 m_shell->activation()->activate(token, window()->wlSurface());
             });
@@ -268,13 +250,6 @@ void QWaylandLayerSurface::requestXdgActivationToken(quint32 serial)
 
 void QWaylandLayerSurface::sendExpose()
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    window()->handleExpose(QRect(QPoint(), m_pendingSize));
-#elif QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
-    window()->sendRecursiveExposeEvent();
-#else
     window()->updateExposure();
-#endif
 }
-
 }
